// script.js

// Define SVG dimensions
const svgWidth = 930;
const svgHeight = 450;

// Define margin
const margin = { top: 20, right: 30, bottom: 70, left: 60 };
const width = svgWidth - margin.left - margin.right;
const height = svgHeight - margin.top - margin.bottom;

// Create SVG element
const svg = d3
  .select('svg')
  .attr('width', svgWidth)
  .attr('height', svgHeight);

// Create group element
const g = svg
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Define x and y scales
const xScale = d3
  .scaleBand()
  .range([0, width])
  .padding(0.1);

const yScale = d3.scaleLinear().range([height, 0]);

// Define x and y axes
const xAxis = d3.axisBottom(xScale);
const yAxis = d3.axisLeft(yScale);

// Load data from CSV
d3.csv(
  'https://raw.githubusercontent.com/kowshiksamudrala08/datasets/main/data_science_salaries.csv',
).then((data) => {
  // Parse data
  data.forEach((d) => {
    d.salary = +d.salary;
    d.work_year = +d.work_year;
  });

  // Set x and y domains
  xScale.domain(data.map((d) => d.work_year));
  yScale.domain([0, d3.max(data, (d) => d.salary)]);

  // Add x-axis
  g.append('g')
    .attr('class', 'x-axis')
    .attr('transform', `translate(0, ${height})`)
    .call(xAxis)
    .selectAll('text')
    .style('text-anchor', 'end')
    .attr('transform', 'rotate(-45)');

  // Add y-axis
  g.append('g').attr('class', 'y-axis').call(yAxis);

  // Create tooltip
  const tooltip = d3
    .select('body')
    .append('div')
    .attr('class', 'tooltip')
    .style('opacity', 0);

  // Add area chart
  g.selectAll('.bar')
    .data(data)
    .enter()
    .append('rect')
    .attr('class', 'bar')
    .attr('x', (d) => xScale(d.work_year))
    .attr('y', (d) => yScale(d.salary))
    .attr('width', xScale.bandwidth())
    .attr('height', (d) => height - yScale(d.salary))
    .attr('fill', 'blue')
    // Add tooltip on mouseover
    .on('mouseover', function (d) {
      tooltip
        .transition()
        .duration(200)
        .style('opacity', 0.9);
      tooltip
        .html(`Year: ${d.work_year}<br>Salary: ${d.salary}`)
        .style('left', d3.event.pageX + 'px')
        .style('top', d3.event.pageY - 28 + 'px');
    })
    // Hide tooltip on mouseout
    .on('mouseout', function (d) {
      tooltip
        .transition()
        .duration(500)
        .style('opacity', 0);
    });
});
